@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -120,6 +120,11 @@ SocketFd::open_datagram() {
   return (m_fd = socket(PF_INET, SOCK_DGRAM, 0)) != -1;
 }
 
+bool
+SocketFd::open_local() {
+  return (m_fd = socket(PF_LOCAL, SOCK_DGRAM, 0)) != -1;
+}
+
 void
 SocketFd::close() {
   if (::close(m_fd) && errno == EBADF)
@@ -133,6 +138,13 @@ SocketFd::bind(const rak::socket_address& sa) {
   return !::bind(m_fd, sa.c_sockaddr(), sa.length());
 }
 
+bool
+SocketFd::bind(const rak::socket_address& sa, unsigned int length) {
+  check_valid();
+
+  return !::bind(m_fd, sa.c_sockaddr(), length);
+}
+
 bool
 SocketFd::connect(const rak::socket_address& sa) {
   check_valid();
