@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -115,11 +115,19 @@ PeerConnectionLeech::receive_keepalive() {
   // should stay at zero or one when downloading at an acceptable
   // speed. Thus only when m_downStall >= 2 is the download actually
   // stalling.
+  //
+  // If more than 6 ticks have gone by, assume the peer forgot about
+  // our requests or tried to cheat with empty piece messages, and try
+  // again.
 
   // TODO: Do we need to remove from download throttle here?
 
-  if (!download_queue()->empty() && m_downStall++ != 0)
-    download_queue()->stall();
+  if (!download_queue()->empty() && m_downStall++ != 0) {
+    if (m_downStall > 6)
+      download_queue()->cancel();
+    else
+      download_queue()->stall();
+  }
 
   return true;
 }
@@ -565,7 +573,7 @@ PeerConnectionLeech::read_have_chunk(uint32_t index) {
       m_sendInterested = !m_downInterested;
       m_downInterested = true;
       
-      // Ensure we get inserted into the chunk manager queue in case
+      // Ensure we get inserted into the choke manager queue in case
       // the peer keeps us unchoked even though we've said we're not
       // interested.
       if (m_downUnchoked)
