@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@
 #include "config.h"
 
 #include <algorithm>
+#include <cstring>
 #include <functional>
 #include <limits>
 #include <memory>
@@ -109,7 +110,7 @@ FileList::is_multi_file() const {
   // Currently only check if we got just one file. In the future this
   // should be a bool, which will be set based on what flags are
   // passed when the torrent was loaded.
-  return size() != 1;
+  return m_isMultiFile;
 }
 
 uint64_t
@@ -346,7 +347,7 @@ FileList::open() {
 
   try {
     if (::mkdir(m_rootDir.c_str(), 0777) != 0 && errno != EEXIST)
-      throw storage_error("Could not create directory '" + m_rootDir + "': " + strerror(errno));
+      throw storage_error("Could not create directory '" + m_rootDir + "': " + std::strerror(errno));
   
     while (itr != end()) {
       File* entry = *itr++;
@@ -440,7 +441,7 @@ FileList::make_directory(Path::const_iterator pathBegin, Path::const_iterator pa
       break;
 
     if (::mkdir(path.c_str(), 0777) != 0 && errno != EEXIST)
-      throw storage_error("Could not create directory '" + path + "': " + strerror(errno));
+      throw storage_error("Could not create directory '" + path + "': " + std::strerror(errno));
   }
 }
 
