@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -194,10 +194,10 @@ TrackerHttp::receive_done() {
 			 + "\"");
 
   if (b.has_key_value("interval"))
-    m_slotSetInterval(b.get_key_value("interval"));
+    set_normal_interval(b.get_key_value("interval"));
   
   if (b.has_key_value("min interval"))
-    m_slotSetMinInterval(b.get_key_value("min interval"));
+    set_min_interval(b.get_key_value("min interval"));
 
   if (b.has_key_string("tracker id"))
     m_trackerId = b.get_key_string("tracker id");
