@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -297,7 +297,7 @@ TrackerUdp::process_announce_output() {
       m_readBuffer->read_32() != m_transactionId)
     return false;
 
-  m_slotSetInterval(m_readBuffer->read_32());
+  set_normal_interval(m_readBuffer->read_32());
 
   m_readBuffer->read_32(); // leechers
   m_readBuffer->read_32(); // seeders
